import pandas as pd
from os.path import dirname, join

# Biological constants
ROOT_RANK = 'root'
RANK_LIST = [
    'forma', 'varietas', 'subspecies', 'species', 'species group', 'species subgroup', 'subgenus',
    'genus', 'tribe', 'subfamily', 'family', 'suborder', 'cohort', 'order', 'infraclass', 'subclass',
    'class', 'subphylum', 'phylum', 'subkingdom', 'kingdom', 'superkingdom', 'no rank', ROOT_RANK
]
CANONICAL_RANKS = ['species', 'genus', 'family', 'order', 'class', 'phylum', 'kingdom']
SPORE_FORMING_GENERA = [
    'Bacillus', 'Clostridium', 'Sporolactobacillus', 'Sporosarcina',
    'Cerasibacillus', 'Alkalibacillus', 'Amphibacillus', 'Anoxybacillus',
    'Filobacillus', 'Geobacillus', 'Gracilibacillus', 'Halobacillus',
    'Lentibacillus', 'Oceanobacillus', 'Paraliobacillus', 'Pontibacillus',
    'Tenuibacillus', 'Thalassobacillus', 'Virgibacillus', 'Jeotgalibacillus',
    'Marinibacillus', 'Planomicrobium', 'Ureibacillus', 'Sporobacterium',
    'Desulfitobacterium', 'Desulfonispora', 'Desulfosporosinus',
    'Desulfotomaculum', 'Sporotomaculum', 'Syntrophobotulus', 'Pelotomaculum',
    'Sporotomaculum', 'Syntrophobotulus', 'Thermincola', 'Filifactor',
    'Tepidibacter', 'Anaerotruncus', 'Oscillospira', 'Sporobacter',
]
NON_SPORE_FORMING_GENERA = [
    'Halolactibacillus', 'Marinococcus', 'Saccharococcus', 'Planococcus',
    'Caryophanon', 'Filibacter', 'Kurthia', 'Peptococcus', 'Cryptanaerobacter',
    'Dehalobacter', 'Anaerofilum', 'Acetivibrio', 'Acetanaerobacterium',
    'Fastidiosipila', 'Papillibacter', 'Subdoligranulum',
]

NEG = 'Negative'
POS = 'Positive'
PHYLUM_GRAM_STAINS = {
    'Bacteroidetes': NEG,
    'Chlorobi': NEG,
    'Cyanobacteria': NEG,
    'Proteobacteria': NEG,
    'Firmicutes': POS,
    'Deinococcus-Thermus': POS,
    'Actinobacteria': POS,
    'Fusobacteria': NEG,
    'Nitrospirae': None,
    'Acidobacteria': None,
    'Fibrobacteres': NEG,
    'Thermodesulfobacteria': None,
    'Caldiserica': None,
    'Armatimonadetes': NEG,
    'Dictyoglomi': NEG,
    'Deferribacteres': NEG,
    'Verrucomicrobia': None,
    'Chrysiogenetes': None,
    'Kiritimatiellaeota': None,
    'Aquificae': NEG,
    'Thermotogae': NEG,
    'Chloroflexi': NEG,
    'Planctomycetes': NEG,
    'Spirochaetes': None,
    'Chlamydiae': NEG,
    'Lentisphaerae': None,
    'Synergistetes': NEG,
    'Tenericutes': None,
    'Ignavibacteriae': None,
    'Nitrospinae': None,
    'Rhodothermaeota': None,
    'Calditrichaeota': None,
    'Balneolaeota': None,
    'Abditibacteriota': None,
    'Coprothermobacterota': None,
}


VIRUS = 'Viruses'
BACTERIA = 'Bacteria'
FUNGI = 'Eukaryota'
ALLOWED_SUPERKINGDOMS = [VIRUS, BACTERIA, FUNGI]
DOMAINS = [el.lower() for el in ALLOWED_SUPERKINGDOMS]

# Programmatic
MICROBE_DIRECTORY_CSV = join(
    dirname(__file__),
    'stored_final_tables/microbe-directory.csv.gz'
)
MICROBE_DIRECTORY = pd.read_csv(MICROBE_DIRECTORY_CSV, index_col=7)


RADIO = set([
    'Arthrobacter sp. RCML-40',
    'Cellulomonas sp. RCML-44',
    'Agrococcus sp. RCML-24',
    'Agrococcus sp. RCML-30',
    'Knoellia sp. RCML-25',
    'Nocardiodes sp. RCML-51',
    'Planomicrobium sp. RCML-41',
    'Pontibacter sp. RCML-14',
    'Pontibacter sp. RCML-11',
    'Rufibacter sp. RCML-10',
    'Microvirga sp. RCML-39',
    'Microvirga sp. RCML-7',
    'Lysobacter xinjiangensis RCML-52',
    'Deinococcus sp. RCML-5',
    'Escherichia coli MG1655',
    'Methylobacterium mesophilicum Ch8',
    'Methylobacterium extorquens 19ch',
    'Kocuria erythromyxa G38',
    'Methylobacterium mesophilicum 8-18',
    'Rhodococcus rhodochorous',
    'Kocuria rosea C2',
    'Methylobacterium extorquens B9',
    'Halobacterium sp. strain NRC1',
    'Bacillus subtilis',
    'Bacillus subtilis 28-95',
    'Deinococcus radiodurans',
    'Deinococcus grandis G8',
    'Deinococcus radiodurans R1',
    'Deinococcus maricopensis LB-34',
    'Deinococcus grandis X2',
    'Deinococcus radiodurans R1',
    'Deinococcus PO-04-20-132T',
    'Deinococcus PO-04-19-125T',
    'Deinococcus ME-04-01-32T',
    'Deinococcus ME-04-04-52T',
    'Halomonas sp. MVT 161',
    'Halomonas sp. MVT 463',
    'Halomonas sp. MVT 464',
    'Halomonas sp. MVT 468',
    'Brevundimonas sp. MV7',
    'Rhodococcus sp. MV10 ',
    'Deinococcus radiodurans',
])

PSYCHRO = set([
    'Arthrobacter alpinus (3)a',
    'Cryobacterium arcticum',
    'Cryobacterium flavum',
    'Cryobacterium levicorallinum',
    'Cryobacterium luteum',
    'Cryobacterium psychrotolerans',
    'Cryobacterium roopkundense',
    'Demequina lutea',
    'Glaciibacter superstes',
    'Leifsonia rubra',
    'Tomitella biformata',
    'Bacillus cecembensis',
    'Bacillus psychrosaccharolyticus',
    'Brochothrix campestris',
    'Lactobacillus algidus',
    'Paenibacillus antarcticus',
    'Paenibacillus glacialis',
    'Paenibacillus macquariensis (2)',
    'Planococcus antarcticus',
    'Planococcus faecalis',
    'Planococcus halocryophilus',
    'Planomicrobium glaciei',
    'Carnobacterium alterfunditum',
    'Carnobacterium funditum',
    'Carnobacterium iners',
    'Carnobacterium pleistocenium',
    'Acetobacterium bakii',
    'Aequorivita sublithincola',
    'Bizionia algoritergicola',
    'Bizionia argentinensis',
    'Bizionia psychrotolerans',
    'Cellulophaga algicola',
    'Chryseobacterium antarcticum',
    'Chryseobacterium frigidisoli',
    'Crocinitomix catalasitica',
    'Flavobacterium antarcticum',
    'Flavobacterium branchiophilum',
    'Flavobacterium degerlachei',
    'Flavobacterium frigidarium',
    'Flavobacterium frigoris',
    'Flavobacterium fryxellicola',
    'Flavobacterium gelidilacus',
    'Flavobacterium gillisiae',
    'Flavobacterium hibernum',
    'Flavobacterium micromati',
    'Flavobacterium noncentrifugens',
    'Flavobacterium omnivorum',
    'Flavobacterium rivuli',
    'Flavobacterium psychrophilum (29)',
    'Flavobacterium sinopsychrotolerans',
    'Flavobacterium sp.',
    'Flavobacterium tegetincola',
    'Flavobacterium xanthum',
    'Flavobacterium xueshanense',
    'Gelidibacter algens',
    'Gillisia limnaea',
    'Lacinutrix algicola',
    'Lacinutrix himadriensis',
    'Lacinutrix jangbogonensis',
    'Lacinutrix mariniflava',
    'Maribacter antarcticus',
    'Polaribacter atrinae',
    'Polaribacter franzmannii',
    'Polaribacter irgensii',
    'Pricia antarctica',
    'Psychroflexus gondwanensis',
    'Psychroflexus torquis',
    'Psychroserpens burtonensis',
    'Psychroserpens jangbogonensis',
    'Rhodonellum psychrophilum    ',
    'Winogradskyella psychrotolerans',
    'Arcticibacter eurypsychrophilus',
    'Arcticibacter svalbardensis',
    'Pedobacter arcticus',
    'Pedobacter hartonius',
    'Hymenobacter psychrophilus',
    'Devosia psychrophila',
    'Glacier cryoconite',
    'Erythrobacter sp.',
    'Phaeobacter arcticus',
    'Octadecabacter antarcticus',
    'Octadecabacter arcticus',
    'Octadecabacter temperatus',
    'Robiginitomaculum antarcticum',
    'Deinococcus-Thermus',
    'Deinococcus frigens',
    'Deinococcus marmoris',
    'Polaromonas glacialis',
    'Polaromonas naphthalenivorans',
    'Simplicispira psychrophila',
    'Aliivibrio logei',
    'Aliivibrio salmonicida',
    'Aliivibrio wodanis',
    'Colwellia chukchiensis',
    'Colwellia hornerae',
    'Colwellia piezophila',
    'Colwellia psychrerythraea (3)',
    'Dasania marina',
    'Glaciecola pallidula',
    'Glaciecola punicea (2)',
    'Idiomarina abyssalis',
    'Idiomarina zobellii',
    'Marinobacter psychrophilus',
    'Marinomonas ushuaiensis',
    'Moritella dasanensis',
    'Moritella marina',
    'Moritella viscosa',
    'Neptunomonas antarctica',
    'Neptunomonas japonica',
    'Oleispira antarctica',
    'Paraglaciecola arctica',
    'Paraglaciecola chathamensis',
    'Paraglaciecola polaris',
    'Paraglaciecola psychrophila',
    'Photobacterium profundum',
    'Pseudoalteromonas arctica',
    'Pseudoalteromonas denitrificans',
    'Psychrobacter arcticus',
    'Psychrobacter cryohalolentis',
    'Psychrobacter glacincola',
    'Psychrobacter urativorans',
    'Psychromonas arctica',
    'Psychromonas hadalis',
    'Psychromonas ingrahamii',
    'Psychromonas ossibalaenae',
    'Shewanella benthica',
    'Shewanella frigidimarina',
    'Shewanella halifaxensis',
    'Shewanella piezotolerans',
    'Shewanella sediminis',
    'Shewanella violacea',
    'Shewanella woodyi',
    'Thiomicrospira arctica',
    'Desulfotalea psychrophila',
    'Desulfovibrio ferrireducens',
    'Desulfovibrio frigidus',
    'Sulfurimonas gotlandica',
    'Methanococcoides burtonii',
    'Methanogenium frigidum',
    'Methanolobus psychrophilus',
])

RADIO_GENUS = {el.split()[0] for el in RADIO}
PSYCHRO_GENUS = {el.split()[0] for el in PSYCHRO}

